@@ -21,8 +21,9 @@ kbd_warning(const int errnum, const char *fmt, ...)
 	vfprintf(stderr, fmt, ap);
 
 	if (errnum > 0)
-		fprintf(stderr, ": %s\n", strerror(errnum));
+		fprintf(stderr, ": %s", strerror(errnum));
 
+	fprintf(stderr, "\n");
 	va_end(ap);
 	return;
 }
@@ -39,7 +40,8 @@ kbd_error(const int exitnum, const int errnum, const char *fmt, ...)
 	va_end(ap);
 
 	if (errnum > 0)
-		fprintf(stderr, ": %s\n", strerror(errnum));
+		fprintf(stderr, ": %s", strerror(errnum));
 
+	fprintf(stderr, "\n");
 	exit(exitnum);
 }
